@@ -33,14 +33,26 @@ from global_chem.medicinal_chemistry.scaffolds.common_r_group_replacements impor
 
 # Proteins Kinases
 
-from global_chem.proteins.kinases.braf.common_groups_by_pocket import BRAFInhibitorsByPocket
-from global_chem.proteins.kinases.scaffolds.privileged_scaffolds import PrivilegedKinaseInhibitorScaffolds
+from global_chem.proteins.kinases.braf.inhibitors import BRAFInhibitors
+from global_chem.proteins.kinases.scaffolds.privileged_kinase_inhibtors import PrivilegedKinaseInhibitors
 
 # Organic Synthesis
 
 from global_chem.organic_synthesis.solvents.common_organic_solvents import CommonOrganicSolvents
 from global_chem.organic_synthesis.protecting_groups.amino_acid_protecting_groups import AminoAcidProtectingGroups
 
+# Narcotics
+
+from global_chem.narcotics.schedule_one import ScheduleOne
+from global_chem.narcotics.schedule_two import ScheduleTwo
+from global_chem.narcotics.schedule_three import ScheduleThree
+from global_chem.narcotics.schedule_four import ScheduleFour
+from global_chem.narcotics.schedule_five import ScheduleFive
+
+# Interstellar Space
+
+from global_chem.interstellar_space.interstellar_space import InterstellarSpace
+
 # Miscellaneous
 
 from global_chem.miscellaneous.vitamins import Vitamins
